@@ -43,6 +43,12 @@ class benedict(KeypathDict, IODict, ParseDict):
             return
         super(benedict, self).__init__(*args, **kwargs)
 
+    def __deepcopy__(self, memo):
+        obj = benedict(keypath_separator=self._keypath_separator)
+        for key, value in self.items():
+            obj[key] = _clone(value, memo=memo)
+        return obj
+
     def __getitem__(self, key):
         return self._cast(
             super(benedict, self).__getitem__(key))
@@ -184,6 +190,7 @@ class benedict(KeypathDict, IODict, ParseDict):
         Merge one or more dict objects into current instance (deepupdate).
         Sub-dictionaries will be merged toghether.
         If overwrite is False, existing values will not be overwritten.
+        If concat is True, list values will be concatenated toghether.
         """
         _merge(self, other, *args, **kwargs)
 
